@@ -33,6 +33,7 @@ class NameJExpr extends AbstractJAssignableExpr {
     }
 
     public void write(final SourceFileWriter writer) throws IOException {
-        writer.writeEscaped(name);
+        writer.addWordSpace();
+        writer.writeEscapedWord(name);
     }
 }
